@@ -1,12 +1,13 @@
 from .file import File
+from .lines import LazyLineObject
 from .array import OneIndexedArray
 from .molecule import Molecule
 from .ensemble import Ensemble, ConformationalEnsemble
 from .group import Group
 
-from .gaussian_file import GaussianFile, JobType
+from .gaussian_file import GaussianFile, GaussianJobType
+from .orca_file import OrcaFile, OrcaJobType
 from .xyz_file import XYZFile
 from .mol2_file import MOL2File
 from .mae_file import MAEFile
-from .orca_file import OrcaFile
 from .pdb_file import PDBFile
