@@ -1,3 +1,7 @@
+"""
+Miscellaneous helper functions.
+"""
+
 import numpy as np
 import math
 import re
@@ -16,27 +20,28 @@ This code populates ELEMENT_DICTIONARY and ISOTOPE_DICTIONARY from a static data
 """
 ELEMENT_DICTIONARY = {}
 ISOTOPE_DICTIONARY = {}
-isotope_file = pkg_resources.open_text(data, "isotopes.csv")
-prev_number = 1
-current_dict = {}
-for line in isotope_file:
-    symbol, number, mass, abundance = line.split(",")
-    if symbol == "Symbol":
-        continue
 
-    ELEMENT_DICTIONARY[number] = symbol
+with pkg_resources.open_text(data, "isotopes.csv") as isotope_file:
+    prev_number = 1
+    current_dict = {}
+    for line in isotope_file:
+        symbol, number, mass, abundance = line.split(",")
+        if symbol == "Symbol":
+            continue
 
-    if number == prev_number:
-        current_dict[float(mass)] = float(abundance.rstrip())
-    else:
-        ISOTOPE_DICTIONARY[prev_number] = current_dict
-        current_dict = {}
-        current_dict[float(mass)] = float(abundance.rstrip())
+        ELEMENT_DICTIONARY[number] = symbol
 
-    prev_number = number
+        if number == prev_number:
+            current_dict[float(mass)] = float(abundance.rstrip())
+        else:
+            ISOTOPE_DICTIONARY[prev_number] = current_dict
+            current_dict = {}
+            current_dict[float(mass)] = float(abundance.rstrip())
 
-ISOTOPE_DICTIONARY[prev_number] = current_dict
-ELEMENT_DICTIONARY["0"] = "Bq"
+        prev_number = number
+
+    ISOTOPE_DICTIONARY[prev_number] = current_dict
+    ELEMENT_DICTIONARY["0"] = "Bq"
 
 INV_ELEMENT_DICTIONARY = {v: int(k) for k, v in ELEMENT_DICTIONARY.items()}
 
@@ -78,15 +83,14 @@ def get_number(atomic_symbol):
 This code populates COVALENT_RADII_DICTIONARY from a static datafile.
 """
 COVALENT_RADII_DICTIONARY = {}
-covalent_radii = pkg_resources.open_text(data, "covalent_radii.csv")
-for line in covalent_radii:
-    line_fragments = line.split(",")
-
-    #### There's a variable number from line to line, but the first three are always number, symbol, radius
-    if line_fragments[1] == "Symbol":
-        continue
-    COVALENT_RADII_DICTIONARY[line_fragments[0]] = line_fragments[2]
+with pkg_resources.open_text(data, "covalent_radii.csv") as covalent_radii:
+    for line in covalent_radii:
+        line_fragments = line.split(",")
 
+        #### There's a variable number from line to line, but the first three are always number, symbol, radius
+        if line_fragments[1] == "Symbol":
+            continue
+        COVALENT_RADII_DICTIONARY[line_fragments[0]] = line_fragments[2]
 
 def get_covalent_radius(atomic_number):
     """
@@ -480,3 +484,105 @@ def scale_nmr_shifts(ensemble, symmetrical_atom_numbers=None, scaling_factors="d
     scaled_shifts = np.array(all_scaled_shifts)
     shift_labels = np.array(all_shift_labels)
     return scaled_shifts, shift_labels
+
+def compute_chirality(v1, v2, v3, v4):
+    """
+    Given 4 bond vectors, returns 1 or -1 based on chirality.
+    For proper Cahn–Ingold–Prelog results, vectors should be passed from highest to lowest priority; however, any predictable order will give meaningful results.
+
+    Args:
+        v1 (np.ndarray): 3D bond vector
+        v2 (np.ndarray): 3D bond vector
+        v3 (np.ndarray): 3D bond vector
+        v4 (np.ndarray): 3D bond vector
+
+    Returns:
+        value of 1 (R by CIP) or -1 (S by CIP)
+    """
+    assert (isinstance(v1, np.ndarray) and len(v1) == 3), "v1 needs to be a 3-element np.ndarray!"
+    assert (isinstance(v2, np.ndarray) and len(v2) == 3), "v2 needs to be a 3-element np.ndarray!"
+    assert (isinstance(v3, np.ndarray) and len(v3) == 3), "v3 needs to be a 3-element np.ndarray!"
+    assert (isinstance(v4, np.ndarray) and len(v4) == 3), "v4 needs to be a 3-element np.ndarray!"
+
+    e1 = np.array([1, 0, 0])
+    e2 = np.array([0, 1, 0])
+    e3 = np.array([0, 0, 1])
+
+    # rotate v4 so that it's pointing back!
+    axis1 = np.cross(v4, e1)
+    theta1 = compute_angle_between(e1, v4)
+
+    R1 = compute_rotation_matrix(axis1, theta1)
+    v1 = R1 @ v1
+    v2 = R1 @ v2
+    v3 = R1 @ v3
+    v4 = R1 @ v4
+
+    assert 1.0 > compute_angle_between(v4, e1), "rotating v4 failed"
+
+    # rotate v1 so that it's pointing up!
+    axis2 = v4
+    theta2 = compute_angle_between(np.array([0, v1[1], v1[2]]), e3) # projection of v1 onto e2•e3 plane
+
+    R2 = compute_rotation_matrix(axis2, np.sign(v1[1]) * theta2)
+    v1 = R2 @ v1
+    v2 = R2 @ v2
+    v3 = R2 @ v3
+    v4 = R2 @ v4
+
+    theta2 = compute_angle_between(np.array([0, 0, v1[2]]), e3) # projection of v1 onto e3
+
+    assert 1.0 > compute_angle_between(v4, e1), f"rotating v4 failed - 1.0 ≤ {compute_angle_between(v4, e1)}"
+    assert 1.0 > compute_angle_between(e3, np.array([0, 0, v1[2]])), f"rotating v1 failed, - 1.0 ≤ {compute_angle_between(e3, np.array([0, 0, v1[2]]))}"
+
+    answer = np.sign(v2[1])
+    assert np.sign(v3[1]) != answer, "at this point our two substituents are on the same side of the plane that's supposed to divide them"
+    return answer
+
+# constants for calculating entropy
+ENTROPY_FACTOR_1 = 1.43877695998381562 # 2.99792458E10 * 6.62606957E-34 / 1.3806488E-23
+ENTROPY_FACTOR_2 = 1.9872041348        # 8.3144621 / 4.184
+
+def get_entropy(frequencies, temperature):
+    """
+        Computes the total entropy of a given set of frequencies.
+
+        Args:
+            frequencies (list): in cm-1
+            temperature (float): in K
+
+        Returns:
+            entropy (float): in hartree
+    """
+    factor0 = ENTROPY_FACTOR_1 / temperature
+    entropy = 0.0
+    for frequency in frequencies:
+        factor = factor0 * frequency
+        temp = factor * 1.0/(math.exp(factor)-1.0) - math.log(1.0-math.exp(-factor))
+        temp = temp * ENTROPY_FACTOR_2
+        entropy += temp
+    return entropy / 627.509469
+
+def get_corrected_free_energy(free_energy, frequencies, frequency_cutoff=100.0, temperature=298.15):
+    """
+        Computes the free energy by moving all positive frequencies below ``frequency_cutoff``
+        to the cutoff.  See Cramer/Truhlar, J. Phys. Chem. B, 2011, 115, 14556.
+
+        Args:
+            free_energy (float): in hartree
+            frequencies (list): in cm-1
+            frequency_cutoff (float): in cm-1
+            temperature (float): in K
+
+        Returns:
+            corrected_free_energy (float): in hartree
+    """
+    low_frequencies = []
+    for frequency in frequencies:
+        if frequency > 0 and frequency < frequency_cutoff:
+            low_frequencies.append(frequency)
+    entropy_uncorrected = get_entropy(low_frequencies, temperature)
+    entropy_corrected = get_entropy([frequency_cutoff], temperature) * len(low_frequencies)
+    entropy_correction = (entropy_uncorrected - entropy_corrected)*temperature/1000.0
+    corrected_free_energy = free_energy + entropy_correction
+    return corrected_free_energy
