@@ -7,7 +7,7 @@ class TestGaussian(unittest.TestCase):
         path = "test/static/gaussian_file.gjf"
         file = cctk.GaussianFile.read_file(path)
         self.assertEqual(file.route_card, "#p opt freq=noraman m062x/6-31g(d) scrf=(smd,solvent=diethylether)")
-        self.assertListEqual(file.job_types, [cctk.JobType.OPT, cctk.JobType.FREQ, cctk.JobType.SP])
+        self.assertListEqual(file.job_types, [cctk.GaussianJobType.OPT, cctk.GaussianJobType.FREQ, cctk.GaussianJobType.SP])
         self.assertDictEqual(file.link0, {"mem": "1GB", "chk": "test.chk"})
         self.assertEqual(file.title, "title")
         self.assertEqual(file.footer, None)
@@ -18,12 +18,18 @@ class TestGaussian(unittest.TestCase):
         self.assertEqual(mol.charge, 0)
         self.assertEqual(mol.multiplicity, 1)
 
+    def test_title(self):
+        path = "test/static/title.out"
+        file = cctk.GaussianFile.read_file(path)
+        title = file.title
+        self.assertEqual(title, "H4,H5:5.280@C1:53.700")
+
     def test_read_out_file(self):
         path = "test/static/gaussian_file.out"
-        file = cctk.GaussianFile.read_file(path)
+        file = cctk.GaussianFile.read_file(path, extended_opt_info=True)
         self.assertEqual(file.route_card, "#p opt freq=noraman m062x/6-31g(d) scrf=(smd,solvent=diethylether)")
         self.assertDictEqual(file.link0, {"mem": "32GB",  "nprocshared": "16"})
-        self.assertListEqual(file.job_types, [cctk.JobType.OPT, cctk.JobType.FREQ, cctk.JobType.SP])
+        self.assertListEqual(file.job_types, [cctk.GaussianJobType.OPT, cctk.GaussianJobType.FREQ, cctk.GaussianJobType.SP])
         self.assertEqual(file.title, "title")
         self.assertEqual(file.footer, None)
         self.assertTrue(isinstance(file.ensemble, cctk.ConformationalEnsemble))
@@ -37,6 +43,16 @@ class TestGaussian(unittest.TestCase):
         self.assertEqual(mol.charge, 0)
         self.assertEqual(mol.multiplicity, 1)
 
+        self.assertEqual(file.ensemble[0, "max_force"], 0.000034)
+        self.assertEqual(file.ensemble[0, "rms_force"], 0.000009)
+        self.assertEqual(file.ensemble[0, "max_displacement"], 0.002266)
+        self.assertEqual(file.ensemble[0, "rms_displacement"], 0.000547)
+        self.assertEqual(file.ensemble[0, "max_gradient"], 0.000048660)
+        self.assertEqual(file.ensemble[0, "rms_gradient"], 0.000012560)
+        self.assertEqual(file.ensemble[0, "max_internal_force"], 0.000033913)
+        self.assertEqual(file.ensemble[0, "rms_internal_force"], 0.000008756)
+        self.assertEqual(file.ensemble[0, "predicted_change_in_energy"], float("-5.572519e-08"))
+
         old_path = "test/static/gaussian_file.gjf"
         new_path = "test/static/new_gjf.gjf"
 
@@ -51,6 +67,10 @@ class TestGaussian(unittest.TestCase):
 
         os.remove(new_path)
 
+        file = cctk.GaussianFile.read_file("test/static/eliminationTS.out")
+        self.assertEqual(file.route_card, "#p opt=modredundant freq=noraman b3lyp/6-31g(d) empiricaldispersion=gd3bj")
+        self.assertEqual(file.footer, "B 48 50 F\nB 2 48 F")
+
     def test_link1_out_file(self):
         path = "test/static/ethane.out"
         f, lines = cctk.GaussianFile.read_file(path, return_lines=True)
@@ -59,9 +79,9 @@ class TestGaussian(unittest.TestCase):
         self.assertEqual(len(f), 3)
         self.assertTrue(all(isinstance(file, cctk.GaussianFile) for file in f))
 
-        self.assertListEqual(f[0].job_types, [cctk.JobType.OPT, cctk.JobType.FREQ, cctk.JobType.SP])
-        self.assertListEqual(f[1].job_types, [cctk.JobType.NMR, cctk.JobType.SP])
-        self.assertListEqual(f[2].job_types, [cctk.JobType.NMR, cctk.JobType.SP])
+        self.assertListEqual(f[0].job_types, [cctk.GaussianJobType.OPT, cctk.GaussianJobType.FREQ, cctk.GaussianJobType.SP])
+        self.assertListEqual(f[1].job_types, [cctk.GaussianJobType.NMR, cctk.GaussianJobType.SP])
+        self.assertListEqual(f[2].job_types, [cctk.GaussianJobType.NMR, cctk.GaussianJobType.SP])
 
 
     def test_write_ensemble(self):
@@ -111,5 +131,6 @@ class TestGaussian(unittest.TestCase):
         ense = file.ensemble
         self.assertEqual(ense[-1, "dipole_moment"], 0.3316)
 
+
 if __name__ == '__main__':
     unittest.main()
